@@ -46,6 +46,7 @@ class Window(QtWidgets.QMainWindow):
     self.visualizations = None  # object that manages custom visualizations
     self.last_process_events = time()  # to update during heavy loads
     self.rebuilding_plots = False  # used by rebuild_plots
+    self.max_hidden_history = args.max_hidden_history
 
     # persistent settings
     self.settings = QtCore.QSettings('OverBoard', 'OverBoard')
@@ -87,6 +88,10 @@ class Window(QtWidgets.QMainWindow):
     self.y_categorical_checkbox = self.create_checkbox(sidebar,
       label='Treat Y as categorical', default=False, setting_name='y_categorical_checkbox')
 
+    self.metrics_subset_dropdown = self.create_dropdown(sidebar,
+      label='Metrics subset', options=[],
+      setting_name='metrics_subset_dropdown', checkable=True)
+
     self.panel_dropdown = self.create_dropdown(sidebar, label='Panels', default='One per metric',
       options=['Single panel', 'One per metric', 'One per run'], setting_name='panel_dropdown')
 
@@ -96,12 +101,19 @@ class Window(QtWidgets.QMainWindow):
     self.merge_dropdown = self.create_dropdown(sidebar, label='Merge', default='Nothing',
       options=['Nothing'], setting_name='merge_dropdown', reset_style=True)
 
-    self.merge_line_dropdown = self.create_dropdown(sidebar, label='Merged line', default='Mean',
-      options=['Mean', 'Median'], setting_name='merge_line_dropdown')
+    (self.merge_line_dropdown, ml_label) = self.create_dropdown(sidebar,
+      label='Merged line', default='Mean', options=['Mean', 'Median'],
+      setting_name='merge_line_dropdown', return_label=True)
 
-    self.merge_shade_dropdown = self.create_dropdown(sidebar, label='Merged shade', default='2 x standard deviations',
-      options=['1 x standard deviation', '2 x standard deviations', '3 x standard deviations',
-      'Maximum and minimum'], setting_name='merge_shade_dropdown')
+    (self.merge_shade_dropdown, ms_label) = self.create_dropdown(sidebar,
+      label='Merged shade', default='2 x standard deviations',
+      options=[f"{i} x standard deviation" for i in range(1, 4)] + ['Maximum and minimum'], setting_name='merge_shade_dropdown', return_label=True)
+
+    # widgets to hide/show (merge options) depending on whether merging is on
+    self.merge_option_widgets = [ml_label, self.merge_line_dropdown,
+      ms_label, self.merge_shade_dropdown]
+    self.merge_dropdown.activated.connect(self.on_merge_dropdown_activated)
+    self.on_merge_dropdown_activated()  # merge options may start hidden
 
     # experiments filter text box
     rows = sidebar.rowCount()
@@ -163,7 +175,7 @@ class Window(QtWidgets.QMainWindow):
     header.setStretchLastSection(True)
     header.setDefaultAlignment(Qt.AlignLeft)
     header.setSectionsMovable(True)
-    header.setTextElideMode(Qt.ElideRight)  # show ellipsis for cut-off headers
+    #header.setTextElideMode(Qt.ElideRight)  # show ellipsis for cut-off headers. note: takes too much space.
     header.setHighlightSections(False)  # no bold header when cells are clicked
 
     table.itemSelectionChanged.connect(self.on_table_select)
@@ -199,11 +211,12 @@ class Window(QtWidgets.QMainWindow):
 
     self.clipboard = QtGui.QApplication.clipboard()
 
-    # load list of previously-hidden experiments. this is looked up when an experiment loads.
+    # load list of previously-hidden experiments. this is looked up when an
+    # experiment loads. use a dict to preserve order and have fast lookups.
     self.hidden_exp_paths = self.settings.value('hidden_exp_paths', None)
     if self.hidden_exp_paths is None:
       self.hidden_exp_paths = []
-    self.hidden_exp_paths = set(self.hidden_exp_paths)
+    self.hidden_exp_paths = {e: None for e in self.hidden_exp_paths}
 
     # compile loaded filter
     self.on_filter_ready()
@@ -211,7 +224,7 @@ class Window(QtWidgets.QMainWindow):
   def process_events_if_needed(self):
     """Process events if enough time has passed, to keep the GUI
     responsive during potentially heavy operations in the main thread"""
-    if time() - self.last_process_events > 0.5:  # limit to once every 0.5 seconds      
+    if time() - self.last_process_events > 0.5:  # limit to once every 0.5 seconds
       QtWidgets.QApplication.processEvents()
       self.last_process_events = time()
 
@@ -238,17 +251,33 @@ class Window(QtWidgets.QMainWindow):
 
     return panel
   
-  def create_dropdown(self, sidebar, label, options, setting_name, default, reset_style=False):
+  def create_dropdown(self, sidebar, label, options, setting_name, default='', reset_style=False, checkable=False, return_label=False):
     """Create a new dropdown menu, associated with a persistent setting"""
     rows = sidebar.rowCount()
-    sidebar.addWidget(QtWidgets.QLabel(label), rows, 0)
-    dropdown = QtWidgets.QComboBox()
-    for option in options:
+    label = QtWidgets.QLabel(label)
+    sidebar.addWidget(label, rows, 0)
+
+    if not checkable:
+      dropdown = QtWidgets.QComboBox()
+    else:
+      dropdown = CheckableComboBox()
+
+    for (idx, option) in enumerate(options):
       dropdown.addItem(option)
-    dropdown.setCurrentText(self.settings.value(setting_name, default, type=str))
-    dropdown.activated.connect(partial(self.rebuild_plots, reset_style=reset_style))
+
+    if not checkable:
+      default = self.settings.value(setting_name, default, type=str)
+      if default:
+        dropdown.setCurrentText(default)
+    
+    signal = partial(self.rebuild_plots, reset_style=reset_style)
+    if not checkable:
+      dropdown.activated.connect(signal)
+    else:
+      dropdown.view().clicked.connect(signal)
+
     sidebar.addWidget(dropdown, rows, 1)
-    return dropdown
+    return (dropdown if not return_label else (dropdown, label))
 
   def create_checkbox(self, sidebar, label, setting_name, default):
     """Create a new checkbox, associated with a persistent setting"""
@@ -355,7 +384,7 @@ class Window(QtWidgets.QMainWindow):
         if arg_name not in table_col_by_name:  # a new argument name, add a column
           col = table.columnCount()
           table.setColumnCount(col + 1)
-          table.setHorizontalHeaderItem(col, QtWidgets.QTableWidgetItem(arg_name))  #, QtWidgets.QTableWidgetItem.Type
+          table.setHorizontalHeaderItem(col, QtWidgets.QTableWidgetItem(arg_name))  # , QtWidgets.QTableWidgetItem.Type
           table_col_by_name[arg_name] = col
           added_columns = True
         else:
@@ -391,11 +420,14 @@ class Window(QtWidgets.QMainWindow):
   def on_exp_header_ready(self, exp):
     """Called by Experiment when the header data (metrics/column names) has been read"""
     # update dropdown lists to include all metric names
+    unchecked = self.settings.value('metrics_subset_dropdown', [])
     for name in exp.metrics:
       if self.x_dropdown.findText(name) < 0:
         self.x_dropdown.addItem(name)
       if self.y_dropdown.findText(name) < 0:
         self.y_dropdown.addItem(name)
+      if self.metrics_subset_dropdown.findText(name) < 0:
+        self.metrics_subset_dropdown.addItem(name, checked=name not in unchecked)
 
   def rebuild_plots(self, reset_style=False):
     """Rebuild all plots (e.g. when plot options such as x/y axis change)"""
@@ -460,7 +492,7 @@ class Window(QtWidgets.QMainWindow):
     """Toggle visibility of a given experiment, when the
     icon (first column of table) is clicked"""
 
-    if exp.is_filtered: return  # shouldn't happen    
+    if exp.is_filtered: return  # shouldn't happen
     if exp.visible:
       # remove all associated plots, and reset the experiment style so it can be used by others
       exp.visible = False
@@ -643,6 +675,12 @@ class Window(QtWidgets.QMainWindow):
   #def smooth_slider_changed(self):
   #  self.smoother = Smoother(self.smooth_slider.value() / 4.0)
 
+  def on_merge_dropdown_activated(self):
+    """Show/hide other merge options depending on whether merging is on"""
+    visibility = (self.merge_dropdown.currentText() != 'Nothing')
+    for widget in self.merge_option_widgets:
+      widget.setVisible(visibility)
+
   def scroll_wheel_event(self, event):
     """Override QScrollArea wheelEvent, to prevent it from scrolling simultaneously with PyQtGraph's PlotItem"""
     # if one of the panels/plots of the flow layout is under
@@ -668,14 +706,24 @@ class Window(QtWidgets.QMainWindow):
 
     self.settings.setValue('filter_edit', self.filter_edit.text())
 
+    # save unchecked metric subset, up to 50 entries
+    checked_subset = set(self.metrics_subset_dropdown.get_checked_list())
+    unchecked_subset = {m: None for m in self.settings.value('metrics_subset_dropdown') if m not in checked_subset}  # previously hidden but now checked again
+    unchecked_subset.update({m: None for m in self.metrics_subset_dropdown.get_checked_list(unchecked=True)})  # merge with newly hidden
+    if len(unchecked_subset) > 50:  # keep N last
+      unchecked_subset = list(unchecked_subset)[-50:]
+    self.settings.setValue('metrics_subset_dropdown', list(unchecked_subset))
+
     # save auto-complete model for filter, up to 50 entries
     m = self.filter_edit.completer().model()
     history = [m.data(m.index(i), 0) for i in range(min(50, m.rowCount()))]
     self.settings.setValue('filter_completer', history)
 
-    # save hidden status of individual experiments
-    hidden_exp_paths = [exp.directory for exp in self.experiments.exps.values() if not exp.visible]
-    self.settings.setValue('hidden_exp_paths', hidden_exp_paths)
+    # save hidden status of individual experiments, preserving order
+    self.hidden_exp_paths.update({exp.directory: None for exp in self.experiments.exps.values() if not exp.visible})
+    if len(self.hidden_exp_paths) > self.max_hidden_history:  # keeping N last
+      self.hidden_exp_paths = list(self.hidden_exp_paths)[-self.max_hidden_history:]
+    self.settings.setValue('hidden_exp_paths', list(self.hidden_exp_paths))
 
     self.settings.sync()
     event.accept()
@@ -691,6 +739,37 @@ class SortableTableItem(QtWidgets.QTableWidgetItem):
   def __lt__(self, other):
     return (self.data(table_data_order)() < other.data(table_data_order)())
 
+
+class CheckableComboBox(QtGui.QComboBox):
+  """Drop-down list with checkable items"""
+  def __init__(self, parent=None):
+    super().__init__(parent)
+    self.setEditable(True)
+    self.view().clicked.connect(self.refresh_text)
+
+  def addItem(self, text, checked=False):
+    super().addItem(text)
+    item = self.model().item(self.count() - 1)
+    item.setFlags(Qt.ItemIsUserCheckable | Qt.ItemIsEnabled)
+    item.setCheckState(Qt.Checked if checked else Qt.Unchecked)
+    self.refresh_text()
+
+  def refresh_text(self, item=None):
+    """Shows the checked items as a comma-separated list in the QComboBox"""
+    # setCurrentText doesn't work for non-editable QComboBox, so do this
+    line = self.lineEdit()
+    line.setText(', '.join(self.get_checked_list()))
+    line.setReadOnly(True)
+    line.setCursorPosition(0)
+  
+  def get_checked_list(self, unchecked=False):
+    """Return a list of strings containing the checked items"""
+    model = self.model()
+    items = [model.item(i) for i in range(model.rowCount())]
+    state = (Qt.Unchecked if unchecked else Qt.Checked)
+    return [str(item.text()) for item in items if item.checkState() == state]
+
+
 def create_scroller():
   scroll_area = QtWidgets.QScrollArea()
   scroll_area.setWidgetResizable(True)
@@ -714,6 +793,8 @@ def set_style(app):
   app.setStyle("Fusion")
 
   directory = os.path.dirname(os.path.realpath(__file__))
+
+  QtGui.QFontDatabase.addApplicationFont(directory + './assets/OpenSans-Regular.ttf')
   
   with open(directory + '/style.qss', 'r') as file:
     app.setStyleSheet(file.read())
